@@ -93,9 +93,9 @@ NAG_BLACK_SEVERE_TIME_PRESSURE = 139
 NAG_NOVELTY = 146
 
 
-TAG_REGEX = re.compile(r"^\[([A-Za-z0-9_]+)\s+\"([^\r]*)\"\]\s*$")
+TAG_REGEX = re.compile(r"^\[([A-Za-z0-9][A-Za-z0-9_+#=:-]*)\s+\"([^\r]*)\"\]\s*$")
 
-TAG_NAME_REGEX = re.compile(r"^[A-Za-z0-9_]+\Z")
+TAG_NAME_REGEX = re.compile(r"^[A-Za-z0-9][A-Za-z0-9_+#=:-]*\Z")
 
 MOVETEXT_REGEX = re.compile(r"""
     (
@@ -934,7 +934,7 @@ class Headers(MutableMapping[str, str]):
         if key in TAG_ROSTER:
             self._tag_roster[key] = value
         elif not TAG_NAME_REGEX.match(key):
-            raise ValueError(f"non-alphanumeric pgn header tag: {key!r}")
+            raise ValueError(f"invalid pgn header tag: {key!r}")
         elif "\n" in value or "\r" in value:
             raise ValueError(f"line break in pgn header {key}: {value!r}")
         else:
@@ -1466,7 +1466,8 @@ def read_game(handle: TextIO, *, Visitor: Any = GameBuilder) -> Any:
     By using text mode, the parser does not need to handle encodings. It is the
     caller's responsibility to open the file with the correct encoding.
     PGN files are usually ASCII or UTF-8 encoded, sometimes with BOM (which
-    this parser automatically ignores).
+    this parser automatically ignores). See :func:`open` for options to
+    deal with encoding errors.
 
     >>> pgn = open("data/pgn/kasparov-deep-blue-1997.pgn", encoding="utf-8")
 
@@ -1538,7 +1539,9 @@ def read_game(handle: TextIO, *, Visitor: Any = GameBuilder) -> Any:
                 if unmanaged_headers is not None:
                     unmanaged_headers[tag_match.group(1)] = tag_match.group(2)
             else:
-                break
+                # Ignore invalid or malformed headers.
+                line = handle.readline()
+                continue
 
         line = handle.readline()
 
