@@ -1,5 +1,5 @@
 # This file is part of the python-chess library.
-# Copyright (C) 2012-2020 Niklas Fiekas <niklas.fiekas@backscattering.de>
+# Copyright (C) 2012-2021 Niklas Fiekas <niklas.fiekas@backscattering.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,6 +14,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import annotations
+
 import chess
 import struct
 import os
@@ -301,10 +303,22 @@ class Entry(NamedTuple):
     """An entry from a Polyglot opening book."""
 
     key: int
+    """The Zobrist hash of the position."""
+
     raw_move: int
+    """
+    The raw binary representation of the move. Use
+    :data:`~chess.polyglot.Entry.move` instead.
+    """
+
     weight: int
+    """An integer value that can be used as the weight for this entry."""
+
     learn: int
+    """Another integer value that can be used for extra information."""
+
     move: chess.Move
+    """The :class:`~chess.Move`."""
 
 
 class _EmptyMmap(bytearray):
@@ -315,6 +329,10 @@ class _EmptyMmap(bytearray):
         pass
 
 
+def _randint(rng: Optional[random.Random], a: int, b: int) -> int:
+    return random.randint(a, b) if rng is None else rng.randint(a, b)
+
+
 class MemoryMappedReader:
     """Maps a Polyglot opening book to memory."""
 
@@ -335,7 +353,7 @@ class MemoryMappedReader:
         except AttributeError:
             pass
 
-    def __enter__(self) -> "MemoryMappedReader":
+    def __enter__(self) -> MemoryMappedReader:
         return self
 
     def __exit__(self, exc_type: Optional[Type[BaseException]], exc_value: Optional[BaseException], traceback: Optional[TracebackType]) -> None:
@@ -454,7 +472,7 @@ class MemoryMappedReader:
         except IndexError:
             return default
 
-    def choice(self, board: Union[chess.Board, int], *, minimum_weight: int = 1, exclude_moves: Container[chess.Move] = [], random=random) -> Entry:
+    def choice(self, board: Union[chess.Board, int], *, minimum_weight: int = 1, exclude_moves: Container[chess.Move] = [], random: Optional[random.Random] = None) -> Entry:
         """
         Uniformly selects a random entry for the given position.
 
@@ -463,7 +481,7 @@ class MemoryMappedReader:
         chosen_entry = None
 
         for i, entry in enumerate(self.find_all(board, minimum_weight=minimum_weight, exclude_moves=exclude_moves)):
-            if chosen_entry is None or random.randint(0, i) == i:
+            if chosen_entry is None or _randint(random, 0, i) == i:
                 chosen_entry = entry
 
         if chosen_entry is None:
@@ -471,7 +489,7 @@ class MemoryMappedReader:
 
         return chosen_entry
 
-    def weighted_choice(self, board: Union[chess.Board, int], *, exclude_moves: Container[chess.Move] = [], random=random) -> Entry:
+    def weighted_choice(self, board: Union[chess.Board, int], *, exclude_moves: Container[chess.Move] = [], random: Optional[random.Random] = None) -> Entry:
         """
         Selects a random entry for the given position, distributed by the
         weights of the entries.
@@ -482,7 +500,7 @@ class MemoryMappedReader:
         if not total_weights:
             raise IndexError()
 
-        choice = random.randint(0, total_weights - 1)
+        choice = _randint(random, 0, total_weights - 1)
 
         current_sum = 0
         for entry in self.find_all(board, exclude_moves=exclude_moves):
